@@ -155,11 +155,15 @@ main (int argc, char *argv[])
      */
     gdm_config_parse_most();
     glade_xml_signal_autoconnect(GUI);
-    gdm_config_parse_remaining();
 	
 	glade_xml_signal_autoconnect(basic_notebook);
 	glade_xml_signal_autoconnect(expert_notebook);
 	glade_xml_signal_autoconnect(system_notebook);
+
+    gdm_config_parse_remaining();
+
+	gtk_clist_column_titles_passive (GTK_CLIST (get_widget ("user_level_clist")));
+   	gtk_clist_column_titles_passive (GTK_CLIST (get_widget ("server_clist")));
 	
 	gtk_clist_append(GTK_CLIST(get_widget("user_level_clist")),
 					  basic_row);					 
