@@ -42,7 +42,7 @@
 #include "gdm.h"
 #include "filecheck.h"
 
-static const gchar RCSid[]="$Id: gdmlogin.c,v 1.29 2001/02/12 07:15:27 jirka Exp $";
+static const gchar RCSid[]="$Id: gdmlogin.c,v 1.32 2001/02/21 06:43:32 jirka Exp $";
 
 static gboolean GdmBrowser;
 static gboolean GdmDebug;
@@ -52,7 +52,7 @@ static gboolean GdmQuiver;
 static gint  GdmRelaxPerms;
 static gboolean GdmSystemMenu;
 static gint  GdmUserMaxFile;
-static gint  GdmXineramaScreen;
+static gint GdmXineramaScreen;
 static gchar *GdmLogo;
 static gchar *GdmWelcome;
 static gchar *GdmBackgroundProg;
@@ -67,8 +67,8 @@ static gchar *GdmGlobalFaceDir;
 static gchar *GdmDefaultFace;
 static gboolean GdmLockPosition;
 static gboolean GdmSetPosition;
-static int GdmPositionX;
-static int GdmPositionY;
+static gint GdmPositionX;
+static gint GdmPositionY;
 
 static GtkWidget *login;
 static GtkWidget *label;
@@ -108,6 +108,14 @@ static pid_t backgroundpid = 0;
 
 static GHashTable *back_locales = NULL;
 
+static void
+setup_cursor (GdkCursorType type)
+{
+	GdkCursor *cursor = gdk_cursor_new (type);
+	gdk_window_set_cursor (GDK_ROOT_PARENT (), cursor);
+	gdk_cursor_destroy (cursor);
+}
+
 static const char *
 gdm_lookup_locale_name (const char *locale)
 {
@@ -549,10 +557,14 @@ gdm_login_parse_config (void)
 
     gnome_config_pop_prefix();
 
+    if (GdmIconMaxWidth < 0) GdmIconMaxWidth = 128;
+    if (GdmIconMaxHeight < 0) GdmIconMaxHeight = 128;
+    if (GdmUserMaxFile < 0) GdmUserMaxFile = 32768;
+    if (GdmXineramaScreen < 0) GdmXineramaScreen = 0;
+
     if (stat (GdmLocaleFile, &unused) == -1)
 	gdm_login_abort ("gdm_login_parse_config: Could not open locale file %s. Aborting!", GdmLocaleFile);
 
-
     /* Disable System menu on non-local displays */
     display = g_getenv ("DISPLAY");
 
@@ -730,8 +742,8 @@ dance (gpointer data)
 		return FALSE;
 	}
 
-	xm = cos (1.01 * t1);
-	ym = sin (0.90 * t2);
+	xm = cos (2.31 * t1);
+	ym = sin (1.03 * t2);
 
 	t1 += 0.03 + (rand () % 10) / 500.0;
 	t2 += 0.03 + (rand () % 10) / 500.0;
@@ -746,14 +758,32 @@ dance (gpointer data)
 	return TRUE;
 }
 
-static void
+static gboolean
 evil (const char *user)
 {
+	static gboolean old_lock;
 	if (dance_handler == 0 &&
 	    strcmp (user, "Start Dancing") == 0) {
+		setup_cursor (GDK_UMBRELLA);
 		dance_handler = gtk_timeout_add (50, dance, NULL);
+		old_lock = GdmLockPosition;
 		GdmLockPosition = TRUE;
+		gtk_entry_set_text (GTK_ENTRY (entry), "");
+		return TRUE;
+	} else if (dance_handler != 0 &&
+		   strcmp (user, "Stop Dancing") == 0) {
+		setup_cursor (GDK_LEFT_PTR);
+		gtk_timeout_remove (dance_handler);
+		dance_handler = 0;
+		GdmLockPosition = old_lock;
+		gtk_entry_set_text (GTK_ENTRY (entry), "");
+		return TRUE;
+	} else if (strcmp (user, "Gimme Random Cursor") == 0) {
+		setup_cursor (((rand () >> 3) % (GDK_LAST_CURSOR/2)) * 2);
+		gtk_entry_set_text (GTK_ENTRY (entry), "");
+		return TRUE;
 	}
+	return FALSE;
 }
 
 static gboolean
@@ -779,7 +809,13 @@ gdm_login_entry_handler (GtkWidget *widget, GdkEventKey *event)
 	    curuser = g_strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
 
 	    /* evilness */
-	    evil (curuser);
+	    if (evil (curuser)) {
+		    g_free (curuser);
+		    curuser = NULL;
+		    gtk_widget_set_sensitive (entry, TRUE);
+		    gtk_widget_grab_focus (entry);	
+		    return TRUE;
+	    }
 	}
 
 	g_print ("%c%s\n", STX, gtk_entry_get_text (GTK_ENTRY (entry)));
@@ -1461,6 +1497,7 @@ create_handle (void)
 			syslog (LOG_WARNING, _("Can't open icon file: %s. Suspending iconify feature!"), GdmIcon);
 		} else {
 			w = gtk_button_new ();
+			gtk_button_set_relief (GTK_BUTTON (w), GTK_RELIEF_NONE);
 			gtk_container_add (GTK_CONTAINER (w),
 					   gtk_arrow_new (GTK_ARROW_DOWN,
 							  GTK_SHADOW_OUT));
@@ -2011,7 +2048,6 @@ gdm_screen_init (void)
 	}
 }
 
-
 int 
 main (int argc, char *argv[])
 {
@@ -2040,6 +2076,8 @@ main (int argc, char *argv[])
     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
     textdomain (PACKAGE);
 
+    setup_cursor (GDK_LEFT_PTR);
+
     gdm_login_parse_config ();
 
     gdm_screen_init ();
